@@ -20,29 +20,37 @@ import re
 import feedparser
 
 
+# Define available Languages:
+# The specific link is assigned to.
 ENGLISH = 'https://anfenglishmobile.com/feed.rss'
 GERMAN = 'https://anfdeutsch.com/feed.rss'
 KURMANJI = 'https://anfkurdi.com/feed.rss'
 SPANISH = 'https://anfespanol.com/feed.rss'
 ARAB = 'https://anfarabic.com/feed.rss'
+
+# RegEx Tag
 HTML_TAG = re.compile(r'<[^>]+>')               # To remove HTML tags later
 
 
 class ANFFeed:
-    '''
-    ANF Feed Parser
-    ===============
+    ''' ANF Feed Parser
 
-    :param source:
+    This class fetches the news posts from
+    one of the links defined at the more up
+    (depending on the chosen language,
+    default="english").
+
+    Parameters
+    ----------
+    source : str
         Link to set;
         Depending on chosen
-        Language;
-    :type source: str
+        Language.
     '''
 
     source = ENGLISH
 
-    def __init__(self):
+    def __init__(self) -> None:
         try:
             self.feed = feedparser.parse(self.source)
         except NameError:
@@ -51,7 +59,7 @@ class ANFFeed:
         self.entries = self.feed.entries
 
     @classmethod
-    def set_language(cls, language):
+    def set_language(cls, language: str) -> None:
         '''
         Set language of link
         ====================
@@ -76,7 +84,7 @@ class ANFFeed:
             raise NotImplementedError()
 
     @property
-    def title(self):
+    def title(self) -> None:
         '''
         Titles Attribute
         ================
@@ -87,7 +95,7 @@ class ANFFeed:
         return titles
 
     @property
-    def summary(self):
+    def summary(self) -> None:
         '''
         Summary Attribute
         =================
@@ -98,7 +106,7 @@ class ANFFeed:
         return summary
 
     @property
-    def detailed(self):
+    def detailed(self) -> None:
         '''
         Detailed Attribute
         ==================
@@ -111,7 +119,7 @@ class ANFFeed:
         return detailed
 
     @property
-    def link(self):
+    def link(self) -> None:
         '''
         Links Attribute
         ===============
@@ -122,21 +130,20 @@ class ANFFeed:
         return links
 
     @property
-    def all_feeds(self):
+    def all_feeds(self) -> None:
         '''
         All Feeds Attribute
         ===================
         '''
         return list(zip(self.title, self.summary, self.link, self.detailed))
 
-    def download_article(self, ident, target, file='html'):
+    def download_article(self, ident, target):
         '''
         Download Article
         ===============
 
         Requests a chosen article
         and writes it to a file
-        (default: HTML).
 
         :param ident: Identifier;
             Can be link or title
@@ -147,25 +154,30 @@ class ANFFeed:
         :param target: Directory
             to write to
         :type target: str
-        :param file: The desired
-            file type to write
-        :type file: str, default
         '''
+        query = self.entries[ident]
+        result = query.content[0]['value']
+        result = HTML_TAG.sub('', result)
+        link = self.link[ident]
+        title = self.title[ident]
+        
+        file_name = target + title + '.txt'
+        with open(file_name, 'a') as f:
+            f.write(title)
+            f.write('\n\n')
+            f.write(link)
+            f.write('\n\n')
+            f.write(result)
+        return f'\n{title} written succesfully to {target}.\n'
+    
 
-        import requests
-
-        # Try first if ident is a link
-        # If not it's the title
-        try:
-            content = requests.get(ident)
-            print(content)
-        except Exception as missing_schema:
-            print(missing_schema)
-        finally:
-            pass
-
-        raise NotImplementedError()
+    def __repr__(self) -> str:
+        return (f'Spider: {self.__class__.__name__}\n'
+                f'URL: {self.source!r}\n'
+                f'Available articles: {len(self.entries)}\n'
+                )
 
 
 if __name__ == '__main__':
-    pass
+    anf = ANFFeed()
+    article = anf.download_article(1, '/home/n0name/')
